California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROP 13 - 2000 AB 1584 (CHAPTER 725, 1999). MACHADO. SAFE DRINKING WATER, CLEAN WATER, WATERSHED PROTECTION, AND FLOOD PROTEC View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
991921 | YES ON 12 AND 13, A PROJECT OF THE PLANNING AND CONSERVATION LEAGUE | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
970866 | NATURE CONSERVANCY ACTION FUND OF CALIFORNIA, THE | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1221999 | NORTHERN CALIFORNIA WATER ASSOCIATION, A COMMITTEE SUPPORTING PROPOSITION 13 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
991829 | CALIFORNIANS FOR SAFE NEIGHBORHOOD PARKS & CLEAN WATER - YES ON PROPOSITIONS 12 & 13 SPONSORED BY CLEAN AIR, CLEAN WATER AND CONSERVATION GROUPS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
991968 | CALIFORNIANS FOR CLEAN, SAFE, RELIABLE WATER YES ON PROPOSITIONS 12/13 | SUPPORT